==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/outputs/CertificateDatastoreCredentialsResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Certificate datastore credentials configuration.
 * @property authorityUrl Authority URL used for authentication.
 * @property clientId [Required] Service principal client ID.
 * @property credentialsType Enum to determine the datastore credentials type.
 * Expected value is 'Certificate'.
 * @property resourceUrl Resource the service principal has access to.
 * @property tenantId [Required] ID of the tenant to which the service principal belongs.
 * @property thumbprint [Required] Thumbprint of the certificate used for authentication.
 */
public data class CertificateDatastoreCredentialsResponse(
    public val authorityUrl: String? = null,
    public val clientId: String,
    public val credentialsType: String,
    public val resourceUrl: String? = null,
    public val tenantId: String,
    public val thumbprint: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.machinelearningservices.outputs.CertificateDatastoreCredentialsResponse):
            CertificateDatastoreCredentialsResponse = CertificateDatastoreCredentialsResponse(
            authorityUrl = javaType.authorityUrl().map({ args0 -> args0 }).orElse(null),
            clientId = javaType.clientId(),
            credentialsType = javaType.credentialsType(),
            resourceUrl = javaType.resourceUrl().map({ args0 -> args0 }).orElse(null),
            tenantId = javaType.tenantId(),
            thumbprint = javaType.thumbprint(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/outputs/CertificateDatastoreCredentialsResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Certificate datastore credentials configuration.
 * @property authorityUrl Authority URL used for authentication.
 * @property clientId [Required] Service principal client ID.
 * @property credentialsType Enum to determine the datastore credentials type.
 * Expected value is 'Certificate'.
 * @property resourceUrl Resource the service principal has access to.
 * @property tenantId [Required] ID of the tenant to which the service principal belongs.
 * @property thumbprint [Required] Thumbprint of the certificate used for authentication.
 */
public data class CertificateDatastoreCredentialsResponse(
    public val authorityUrl: String? = null,
    public val clientId: String,
    public val credentialsType: String,
    public val resourceUrl: String? = null,
    public val tenantId: String,
    public val thumbprint: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.machinelearningservices.outputs.CertificateDatastoreCredentialsResponse): CertificateDatastoreCredentialsResponse = CertificateDatastoreCredentialsResponse(
            authorityUrl = javaType.authorityUrl().map({ args0 -> args0 }).orElse(null),
            clientId = javaType.clientId(),
            credentialsType = javaType.credentialsType(),
            resourceUrl = javaType.resourceUrl().map({ args0 -> args0 }).orElse(null),
            tenantId = javaType.tenantId(),
            thumbprint = javaType.thumbprint(),
        )
    }
}
